# Tests requiring Internet connections are disabled by default
# pass --with internet to run them (e.g. when doing a local rebuild
# for sanity checks before committing)
%bcond_with internet

%global pypi_name tox

Name:           python-tox
Version:        4.24.1
Release:        %mkrel 2
Summary:        Virtualenv-based automation of test activities
Group:          Development/Python

# file toxbootstrap.py is licensed under MIT License
License:        GPLv2+ and MIT
URL:            https://pypi.org/project/tox/
Source0:        %{pypi_source}
# Remove dependency on devpi-process.
# Remove dependency on detect-test-pollution.
# Remove coverage-related dependencies.
# Adjust virtualenv environment variables to make it work with our patched virtualenv.
Patch:          fix-tests.patch
BuildArch:      noarch
BuildRequires:  python3-devel

%description
Tox as is a generic virtualenv management and test command line tool you
can use for:

 - checking your package installs correctly with different Python versions
   and interpreters
 - running your tests in each of the environments, configuring your test tool
   of choice
 - acting as a frontend to Continuous Integration servers, greatly reducing
   boilerplate and merging CI and shell-based testing.

%package -n python3-%{pypi_name}
Summary:        Virtualenv-based automation of test activities
Group:          Development/Python
%{?python_provide:%python_provide python3-%{pypi_name}}
Requires:	python3-py
Requires:	python3-pluggy
# python3-virtualenv is rhbz#537246
Requires:	python3-virtualenv

%description -n python3-%{pypi_name}
Tox as is a generic virtualenv management and test command line tool you
can use for:

 - checking your package installs correctly with different Python versions
   and interpreters
 - running your tests in each of the environments, configuring your test tool
   of choice
 - acting as a frontend to Continuous Integration servers, greatly reducing
   boilerplate and merging CI and shell-based testing.

%prep
%autosetup -p1 -n %{pypi_name}-%{version}

# Upstream updates dependencies too aggressively
# see https://github.com/tox-dev/tox/pull/2843#discussion_r1065028356
sed -ri -e 's/"(packaging|filelock|platformdirs|psutil|diff-cover|pyproject-api|pytest|pytest-mock|pytest-xdist|wheel|pluggy|distlib|cachetools)>=.*/"\1",/g' \
        -e "s/'(time-machine)>=[^;']+/'\1/" \
        -e 's/"(virtualenv)>=.*/"\1>=20",/g' \
        -e 's/"(hatchling)>=.*/"\1>=1.13",/g' \
    pyproject.toml

%generate_buildrequires
export SETUPTOOLS_SCM_PRETEND_VERSION="%{version}"
%pyproject_buildrequires

%build
export SETUPTOOLS_SCM_PRETEND_VERSION="%{version}"
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files %{pypi_name}

# if internet connection available, run tests
%if %{with internet}
%check
%tox
%endif

%files -n python3-tox -f %{pyproject_files}
%license LICENSE
%{_bindir}/%{pypi_name}


%changelog
* Wed Jul 02 2025 umeabot <umeabot> 4.24.1-2.mga10
+ Revision: 2236285
- Mageia 10 Mass Rebuild

* Sat Feb 22 2025 wally <wally> 4.24.1-1.mga10
+ Revision: 2150824
- new version 4.24.1
- rebuild for python3.13
+ papoteur <papoteur>
- new version 4.14.2

* Wed Dec 20 2023 tv <tv> 4.11.1-1.mga10
+ Revision: 2020416
- 4.11.1

* Thu Dec 07 2023 wally <wally> 3.27.1-2.mga10
+ Revision: 2015165
- rebuild for py3.12
- use %%pyproject_buildrequires

* Fri Nov 18 2022 kekepower <kekepower> 3.27.1-1.mga9
+ Revision: 1908716
- Rediff Patch0
- Update to version 3.27.1

* Tue Sep 06 2022 wally <wally> 3.25.1-1.mga9
+ Revision: 1884498
- new version 3.25.1
- switch build to use pyproject rpm macros

* Tue Mar 29 2022 umeabot <umeabot> 3.23.0-4.mga9
+ Revision: 1832164
- Mageia 9 Mass Rebuild

* Sat Feb 12 2022 tv <tv> 3.23.0-3.mga9
+ Revision: 1773469
- Rebuild for python-3.10

* Mon Mar 15 2021 neoclust <neoclust> 3.23.0-2.mga9
+ Revision: 1703221
- Rebuild against python 3.9

* Wed Mar 03 2021 guillomovitch <guillomovitch> 3.23.0-1.mga9
+ Revision: 1697489
- new version 3.23.0
- fix automatic dependencies

* Mon Mar 01 2021 guillomovitch <guillomovitch> 3.22.0-1.mga9
+ Revision: 1695272
- new version 3.22.0

* Sun Mar 29 2020 wally <wally> 3.14.6-1.mga8
+ Revision: 1562172
- new version 3.14.6

* Sun Feb 16 2020 umeabot <umeabot> 3.14.0-2.mga8
+ Revision: 1530981
- Mageia 8 Mass Rebuild

* Sat Sep 07 2019 wally <wally> 3.14.0-1.mga8
+ Revision: 1438147
- new version 3.14.0
- drop python2 support
- rebuild for python3.8

* Sat Apr 20 2019 wally <wally> 3.9.0-1.mga7
+ Revision: 1393916
- new version 3.9.0

* Mon Jan 07 2019 wally <wally> 3.0.0-0.rc1.3.mga7
+ Revision: 1350664
- rebuild for python3.7

* Fri Sep 21 2018 umeabot <umeabot> 3.0.0-0.rc1.2.mga7
+ Revision: 1290431
- Mageia 7 Mass Rebuild

* Tue Feb 06 2018 guillomovitch <guillomovitch> 3.0.0-0.rc1.1.mga7
+ Revision: 1199387
- new version 3.0.0rc1

* Sat Aug 05 2017 pterjan <pterjan> 2.3.1-3.mga7
+ Revision: 1135667
- Rebuild for python 3.6

* Sun May 15 2016 ngompa <ngompa> 2.3.1-2.mga6
+ Revision: 1015696
- imported package python-tox


* Sat May 14 2016 Neal Gompa <ngompa13@gmail.com> - 2.3.1-2
- Port to Mageia

* Mon Feb 29 2016 Matthias Runge <mrunge@redhat.com> - 2.3.1-1
- update to 2.3.1

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Nov 12 2015 Kalev Lember <klember@redhat.com> - 2.1.1-3
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5

* Tue Aug 25 2015 Matthias Runge <mrunge@redhat.com> - 2.1.1-2
- add requirement: python-pluggy

* Tue Aug 18 2015 Matthias Runge <mrunge@redhat.com> - 2.1.1-1
- update to 2.1.1

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.8.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Dec 16 2014 Matthias Runge <mrunge@redhat.com> - 1.8.1-1
- update to 1.8.1

* Wed Aug 13 2014 Matthias Runge <mrunge@redhat.com> - 1.7.1-3
- Fix ConfigError: ConfigError: substitution key 'posargs' not found
  (rhbz#1127961, rhbz#1128562)

* Wed Jul 30 2014 Matthias Runge <mrunge@redhat.com> - 1.7.1-2
- require virtualenv >= 1.11.2 (rhbz#1122603)

* Tue Jul 08 2014 Matthias Runge <mrunge@redhat.com> - 1.7.1-1
- update to 1.7.1 (rhbz#111797)

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Tue Sep 24 2013 Matthias Runge <mrunge@redhat.com> - 1.6.1-1
- update to 1.6.1

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.2-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.2-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Nov 14 2012 Matthias Runge <mrunge@redhat.com> - 1.4.2-7
- add requires python-py, python-virtualenv (rhbz#876246)

* Thu Oct 18 2012 Matthias Runge <mrunge@redhat.com> - 1.4.2-6
- change license to GPLv2+ and MIT

* Tue Oct 16 2012 Matthias Runge <mrunge@redhat.com> - 1.4.2-5
- totally disable python3 support for now

* Fri Oct 12 2012 Matthias Runge <mrunge@redhat.com> - 1.4.2-4
- conditionalize checks, as internet connection required, not available on koji

* Thu Oct 11 2012 Matthias Runge <mrunge@redhat.com> - 1.4.2-3
- buildrequirement: virtualenv
- disable python3-tests because of missing build-requirement python3-virtualenv

* Wed Oct 10 2012 Matthias Runge <mrunge@redhat.com> - 1.4.2-2
- include tests

* Tue Oct 09 2012 Matthias Runge <mrunge@redhat.com> - 1.4.2-1
- initial packaging
